#
# spec file for package cli11
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define upstream_name CLI11

Name:           cli11
Version:        2.1.2
Release:        bp154.1.24
Summary:        Command line parser for C++11
License:        BSD-3-Clause
Group:          Development/Libraries/C and C++

URL:            https://github.com/CLIUtils/CLI11
Source:         %{upstream_name}-%{version}.tar.gz
BuildRequires:  boost-devel
BuildRequires:  cmake
BuildRequires:  doxygen
BuildRequires:  gcc-c++
BuildRequires:  python3-devel

%description
CLI11 is a command line parser for C++11 and beyond that provides a
rich feature set.

%package devel
Summary:        Development files for CLI11

%description devel
CLI11 is a command line parser for C++11 and beyond that provides a
rich feature set. It is header only, and has a number of design
limits by choice:

 * No completion of partial options (like --ve for --version,
   if it were unambiguous)
 * No wide strings/Unicode

%package      doc
Summary:        Documentation for CLI11
Group:          Documentation/Other

%description  doc
This package contains documentation for CLI11

CLI11 is a command line parser for C++11 and beyond that provides a
rich feature set. It is header only, and has a number of design
limits by choice:

 * No completion of partial options (like --ve for --version,
   if it were unambiguous)
 * No wide strings/Unicode

%prep
%autosetup -p1 -n %{upstream_name}-%{version}

%build
%cmake -DCLI11_BUILD_TESTS:BOOL=FALSE -DCLI11_BUILD_DOCS:BOOL=TRUE -DCLI11_BUILD_EXAMPLES:BOOL=FALSE
%cmake_build all docs

%install
%cmake_install

%files devel
%license LICENSE
%doc CHANGELOG.md
%dir %{_includedir}/CLI
%{_includedir}/CLI/*.hpp
%dir %{_datadir}/cmake/CLI11/
%{_datadir}/cmake/CLI11/*.cmake
%{_datadir}/pkgconfig/CLI11.pc

%files doc
%doc build/docs/html/

%changelog
* Mon Nov 22 2021 Haochuan Chen <yjcoshc@mail.nankai.edu.cn>
- Build doc package
- Include pkgconfig file
- Disable the build of examples
- Change the directory of cmake files to %%{_datadir}/cmake
- Use the upstream name for source and building, and keep the
  package name lowercase
- Update to version 2.1.2
  * Use main for the main branch of the repository
  * Bugfix(cmake): Enforce at least C++11 when using CMake target
  * Build: Don't run doxygen and CTest includes if a submodule
  * Build: Avoid a warning on CMake 3.22
  * Build: Support compiling the tests with an external copy of Catch2
* Thu Oct  8 2020 Jan Engelhardt <jengelh@inai.de>
- Trim conjecture from description and supply actual limits.
* Fri Sep 25 2020 Nicolas Morey-Chaisemartin <nmoreychaisemartin@suse.com>
- Initial import of CLI11 1.9.1
